# CrapGPT

## Introduction

CrapGPT is a tool for bidirectional prediction between human [gut microbiome](https://en.wikipedia.org/wiki/Gut_microbiota) profiles and corresponding dietary patterns.

## Installation and Basic Usage

CrapGPT will be available through PyPI. Once available, we recommend installing CrapGPT into an environment (for instance, a [conda](https://docs.conda.io/en/latest/) environment using a python version of x.

Run the following commands to install crapgpt:

```
pip install crapgpt
```
Try running the command `crapgpt --help` to ensure that CrapGPT has been installed properly.

#### Available commands

CrapGPT provides three commands: `crapgpt train --input_data`, `crapgpt evaluate` and `crapgpt stats`

#### Input Files

CrapGPT takes the following filetypes as input:
